aboutsummaryrefslogtreecommitdiff
path: root/include/elf/ppc64.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/elf/ppc64.h')
-rw-r--r--include/elf/ppc64.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/include/elf/ppc64.h b/include/elf/ppc64.h
index 307d4c2..43090dd 100644
--- a/include/elf/ppc64.h
+++ b/include/elf/ppc64.h
@@ -155,8 +155,12 @@ START_RELOC_NUMBERS (elf_ppc64_reloc_type)
RELOC_NUMBER (R_PPC64_ENTRY, 118)
#ifndef RELOC_MACROS_GEN_FUNC
-/* Fake relocation only used internally by ld. */
+/* Relocation only used internally by ld. If you need to use these
+ reloc numbers, you can change them to some other unused value
+ without affecting the ABI. They will never appear in object files. */
RELOC_NUMBER (R_PPC64_LO_DS_OPT, 128)
+/* Reloc only used internally by gas. As above, value is unimportant. */
+ RELOC_NUMBER (R_PPC64_16DX_HA, 129)
#endif
/* Power9 split rel16 for addpcis. */